Module fields

Module fields 

Field-level diff within a single node, and severity classification.

Structs

FieldChange
A change to a single field within a node.

Enums

FieldValueSnapshot
A serializable snapshot of a field value for display in reports.