validate

Function validate 

pub fn validate(
    agm_file: &AgmFile,
    source: &str,
    file_name: &str,
    options: &ValidateOptions,
) -> DiagnosticCollection
Validates a parsed AGM file against all spec rules.

Runs all validation passes in dependency order and returns a DiagnosticCollection with all diagnostics sorted by line number (ascending), then by severity (errors before warnings at the same line).