Field-level diff within a single node, and severity classification.
Structs
- Field
Change - A change to a single field within a node.
Enums
- Field
Value Snapshot - A serializable snapshot of a field value for display in reports.
Field-level diff within a single node, and severity classification.