Primitive field types, enums, and spans used throughout the AGM model.
Structs
- Parse
Enum Error - Error returned when parsing a string into an enum variant fails.
- Span
- Source location span for diagnostics. Line numbers are 1-indexed.
Enums
- Confidence
- Field
Value - A dynamically-typed AGM field value.
- Node
Status - Node
Type - Priority
- SddPhase
- Suggests the SDD pipeline phase the ticket belongs to (spec 14.4.2).
- Stability
- Ticket
Action - Declares the intent of a ticket emission (spec 14.4.1).