Module fields

Module fields 

Primitive field types, enums, and spans used throughout the AGM model.

Structs

ParseEnumError
Error returned when parsing a string into an enum variant fails.
Span
Source location span for diagnostics. Line numbers are 1-indexed.

Enums

Confidence
FieldValue
A dynamically-typed AGM field value.
NodeStatus
NodeType
Priority
Stability