Primitive field types, enums, and spans used throughout the AGM model.
Structs
- Parse
Enum Error - Error returned when parsing a string into an enum variant fails.
- Span
- Source location span for diagnostics. Line numbers are 1-indexed.
Enums
- Confidence
- Field
Value - A dynamically-typed AGM field value.
- Node
Status - Node
Type - Priority
- Stability